==> red5pro-0.0.14.tar.gz: example/lib/streming_view.dart <==
import 'package:flutter/material.dart';
import 'package:red5pro/red5_configuration.dart';
import 'package:red5pro/red5_stream_view.dart';

class StreamingView extends StatefulWidget {
  final Red5Configuration red5configuration;
  final String streamName;

  const StreamingView(
      {required this.red5configuration, required this.streamName, Key? key})
      : super(key: key);

  @override
  _StreamingViewState createState() => _StreamingViewState();
}

class _StreamingViewState extends State<StreamingView> {
  late R5StreamViewController r5streamViewController;
  bool isPublishing = false;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Red5Pro Streaming'),
        ),
        body: Column(
          children: [
            Expanded(
              child: Red5StreamView(
                red5configuration: widget.red5configuration,
                height: MediaQuery.of(context).size.height.toInt(),
                width: MediaQuery.of(context).size.width.toInt(),
                onR5StreamViewCreated: (controller) {
                  r5streamViewController = controller;
                },
              ),
            ),
            SizedBox(
              width: double.maxFinite,
              child: TextButton(
                child: Text(isPublishing ? 'Stop' : 'Start Streaming'),
                onPressed: () {
                  if (isPublishing) {
                    r5streamViewController.stopStreaming().then((value) {
                      setState(() {
                        isPublishing = false;
                      });
                    });
                  } else {
                    r5streamViewController
                        .startStreaming(widget.streamName, RecordType.Live)
                        .then((value) {
                      setState(() {
                        isPublishing = true;
                      });
                    });
                  }
                },
              ),
            )
          ],
        ),
        floatingActionButton: FloatingActionButton(
          child: Icon(Icons.cameraswitch),
          onPressed: () {
            r5streamViewController.switchCamera();
          },
        ),
      ),
    );
  }
}

==> red5pro-0.0.27.tar.gz: example/lib/streming_view.dart <==
import 'package:flutter/material.dart';
import 'package:red5pro/red5_configuration.dart';
import 'package:red5pro/red5_stream_view.dart';

class StreamingView extends StatefulWidget {
  final Red5Configuration red5configuration;
  final String streamName;

  const StreamingView(
      {required this.red5configuration, required this.streamName, Key? key})
      : super(key: key);

  @override
  _StreamingViewState createState() => _StreamingViewState();
}

class _StreamingViewState extends State<StreamingView> {
  late R5StreamViewController r5streamViewController;
  bool isPublishing = false;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Red5Pro Streaming'),
        ),
        body: Column(
          children: [
            Expanded(
              child: Red5StreamView(
                onR5StreamViewCreated: (controller) {
                  r5streamViewController = controller;
                },
              ),
            ),
            SizedBox(
              width: double.maxFinite,
              child: TextButton(
                child: Text(isPublishing ? 'Stop' : 'Start Streaming'),
                onPressed: () {
                  if (isPublishing) {
                    r5streamViewController.stopStreaming().then((value) {
                      setState(() {
                        isPublishing = false;
                      });
                    });
                  } else {
                    r5streamViewController
                        .startStreaming(widget.red5configuration,
                            widget.streamName, RecordType.Live)
                        .then((value) {
                      setState(() {
                        isPublishing = true;
                      });
                    });
                  }
                },
              ),
            )
          ],
        ),
        floatingActionButton: FloatingActionButton(
          child: Icon(Icons.cameraswitch),
          onPressed: () {
            r5streamViewController.switchCamera();
          },
        ),
      ),
    );
  }
}
